@@ -1,4 +1,4 @@
-package Dist::Zilla::PluginBundle::Author::Plicease 2.52 {
+package Dist::Zilla::PluginBundle::Author::Plicease 2.53 {
 
   use 5.014;
   use Moose;
@@ -17,11 +17,6 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.52 {
   with 'Dist::Zilla::Role::PluginBundle::Easy';
 
   sub mvp_multivalue_args { qw(
-    alien_build_command
-    alien_install_command
-    alien_auto_include
-    alien_bin_requires
-    alien_helper
     upgrade
     preamble
     diag_preamble
@@ -109,16 +104,7 @@ package Dist::Zilla::PluginBundle::Author::Plicease 2.52 {
       }
       if(defined $installer && $installer eq 'Alien')
       {
-        print STDERR Term::ANSIColor::color('bold red') if -t STDERR;
-        print STDERR "please do not use the Alien plugin anymore";
-        print STDERR Term::ANSIColor::color('reset') if -t STDERR;
-        print STDERR "\n";
-
-        my %args =
-          map { $_ => $self->payload->{"alien_$_"} }
-          map { s/^alien_//r }
-          grep /^alien_/, keys %{ $self->payload };
-        $self->_my_add_plugin([ Alien => { %args, %mb } ]);
+        die "[Alien] no longer supported as an installer";
       }
       elsif(defined $installer && $installer eq 'ModuleBuild')
       {
@@ -306,7 +292,7 @@ Dist::Zilla::PluginBundle::Author::Plicease - Dist::Zilla plugin bundle used by
 
 =head1 VERSION
 
-version 2.52
+version 2.53
 
 =head1 SYNOPSIS
 
@@ -450,10 +436,6 @@ Specify an alternative to L<[MakeMaker]|Dist::Zilla::Plugin::MakeMaker>
 L<[ModuleBuildTiny]|Dist::Zilla::Plugin::ModuleBuildTiny>, or
 L<[ModuleBuildDatabase]|Dist::Zilla::Plugin::ModuleBuildDatabase> for example).
 
-If installer is L<Alien|Dist::Zilla::Plugin::Alien>, then any options
-with the alien_ prefix will be passed to L<Alien|Dist::Zilla::Plugin::Alien>
-(minus the alien_ prefix).
-
 If installer is L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild>, then any
 options with the mb_ prefix will be passed to L<ModuleBuild|Dist::Zilla::Plugin::ModuleBuild>
 (including the mb_ prefix).
